pitchtools.suggest_clef_for_named_chromatic_pitches
===================================================

.. autofunction:: abjad.tools.pitchtools.suggest_clef_for_named_chromatic_pitches.suggest_clef_for_named_chromatic_pitches
